// --------------------
/// All Bar modules must implement the actions
pub trait BarModuleActions {
    /// Do necessary clean up before starting new fetch
    fn clear(&mut self);

    /// Do necessary processing to generate data for this bar module
    fn generate_data(&mut self);

    /// Return String content to be displayed in the bar
    fn get_content(&self) -> String;

    /// Return a Unicode icon to display before content in the bar.
    /// This icon may differ based on content of the data
    fn get_icon(&self) -> String;
}

pub trait BarModuleDebug {
    /// Print debug information at the end
    fn post_debug(&self);
}

pub mod bar_module_weather;
pub mod bar_module_music;
pub mod bar_module_network;
pub mod bar_module_memory;
pub mod bar_module_cpu;
pub mod bar_module_power;
pub mod bar_module_date;
pub mod bar_module_time;
